@@ -48,7 +48,7 @@ use vars qw/@ISA @EXPORT @EXPORT_OK @EXPORT_TAGS
             $TIMEOUT @MODULES %MODULES %METHODS $AUTOLOAD
             @CURRENCY_RATES_MODULES $USE_EXPERIMENTAL_UA/;
 
-our $VERSION = '1.64_03'; # TRIAL VERSION
+our $VERSION = '1.64_04'; # TRIAL VERSION
 
 @CURRENCY_RATES_MODULES = qw/
     AlphaVantage
@@ -86,7 +86,6 @@ our $VERSION = '1.64_03'; # TRIAL VERSION
     HU
     IndiaMutual
     MarketWatch
-    MorningstarAU
     MorningstarCH
     MorningstarJP
     MorningstarUK
@@ -1722,7 +1721,6 @@ http://www.gnucash.org/
   Finance::Quote::HU,
   Finance::Quote::IndiaMutual,
   Finance::Quote::MarketWatch,
-  Finance::Quote::MorningstarAU,
   Finance::Quote::MorningstarCH,
   Finance::Quote::MorningstarJP,
   Finance::Quote::MorningstarUK,
